@@ -2,7 +2,10 @@ module FormHelper
   def text_f(f, attr, options = {})
     field(f, attr, options) do
       addClass options, "form-control"
-      options[:focus_on_load] = true if options[:focus_on_load].nil? && attr.to_s == 'name'
+      if attr.to_s == 'name'
+        options[:focus_on_load] ||= true
+        options[:autocomplete] ||= "section-#{f.object_name} name"
+      end
       f.text_field attr, options
     end
   end
@@ -119,6 +122,9 @@ module FormHelper
       # that was defined in the struct.
       blank_option.instance_eval('undef to_s', __FILE__, __LINE__) if method.to_s == 'to_s' || id.to_s == 'to_s'
       array.insert(0, blank_option)
+      html_options['data-placeholder'] = blank_value || html_options[:placeholder]
+    elsif html_options[:placeholder]
+      html_options['data-placeholder'] = html_options[:placeholder]
     end
 
     select_options[:disabled] = '' if select_options[:disabled] == include_blank
@@ -127,7 +133,9 @@ module FormHelper
     html_options[:size] = 'col-md-10' if html_options[:multiple]
     field(f, attr, html_options) do
       addClass html_options, "form-control"
-
+      if include_blank.is_a?(TrueClass)
+        addClass html_options, "include_blank"
+      end
       collection_select = f.collection_select(attr, array, id, method, select_options, html_options)
 
       if disable_button
@@ -434,12 +442,26 @@ module FormHelper
 
   def form_select_f(f, attr, array, select_options = {}, html_options = {})
     addClass html_options, "form-control"
+    include_blank = select_options[:include_blank]
+    if include_blank
+      addClass html_options, "include_blank"
+      blank_value = include_blank.is_a?(TrueClass) ? nil : include_blank
+      if array.kind_of?(Array) # incase array is options_for_select
+        array = array.to_a.dup
+        blank_option = [blank_value, nil]
+        array.insert(0, blank_option)
+        select_options.delete(:include_blank)
+      end
+      html_options['data-placeholder'] = blank_value || html_options[:placeholder]
+    elsif html_options[:placeholder]
+      html_options['data-placeholder'] = html_options[:placeholder]
+    end
     f.select attr, array, select_options, html_options
   end
 
   def link_to_add_fields_classes(options = {})
     classes = "btn btn-default #{options[:class]}"
-    classes << ' btn-primary' if options.fetch(:primary_button, true)
+    classes += ' btn-primary' if options.fetch(:primary_button, true)
     classes
   end
 end
