@@ -6,6 +6,7 @@ import { UserIcon, UsersIcon } from '@patternfly/react-icons';
 import { number_to_human_size as NumberToHumanSize } from 'number_helpers';
 import { translate as __ } from '../../../common/I18n';
 import forceSingleton from '../../../common/forceSingleton';
+import { foremanUrl } from '../../../common/helpers';
 import RelativeDateTime from '../../common/dates/RelativeDateTime';
 import HostPowerStatus from './components/HostPowerStatus';
 
@@ -27,6 +28,20 @@ const coreHostsIndexColumns = [
     weight: 50,
     isRequired: true,
   },
+  {
+    columnName: 'organization',
+    title: __('Organization'),
+    wrapper: hostDetails => hostDetails?.organization_name,
+    isSorted: false,
+    weight: 75,
+  },
+  {
+    columnName: 'location',
+    title: __('Location'),
+    wrapper: hostDetails => hostDetails?.location_name,
+    isSorted: false,
+    weight: 80,
+  },
   {
     columnName: 'hostgroup',
     title: __('Host group'),
@@ -82,8 +97,12 @@ const coreHostsIndexColumns = [
     title: __('Last report'),
     wrapper: hostDetails => {
       const lastReport = hostDetails?.last_report;
-      return (
-        <RelativeDateTime defaultValue={__('Unknown')} date={lastReport} />
+      return lastReport ? (
+        <Link to={foremanUrl(`/hosts/${hostDetails.name}/config_reports/last`)}>
+          <RelativeDateTime date={lastReport} />
+        </Link>
+      ) : (
+        __('No report')
       );
     },
     isSorted: true,
@@ -173,13 +192,22 @@ const reportedDataColumns = [
     isSorted: false,
     weight: 1300,
   },
-  // { // TODO: make virtual work
-  //   columnName: 'virtual',
-  //   title: __('Virtual'),
-  //   wrapper: hostDetails => hostDetails?.reported_data?.virtual,
-  //   isSorted: false,
-  //   weight: 1400,
-  // },
+  {
+    columnName: 'virtual',
+    title: __('Virtual'),
+    wrapper: hostDetails => {
+      const value = hostDetails?.reported_data?.virtual;
+      if (value === undefined || value === null) {
+        return '';
+      }
+      if (value) {
+        return __('Virtual');
+      }
+      return __('Physical');
+    },
+    isSorted: false,
+    weight: 1400,
+  },
   {
     columnName: 'disks_total',
     title: __('Total disk space'),
